# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NlbServerGroupArgs', 'NlbServerGroup']

@pulumi.input_type
class NlbServerGroupArgs:
    def __init__(__self__, *,
                 protocol: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 any_port_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bypass_security_group_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input['NlbServerGroupHealthCheckArgs']] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 preserve_client_ip_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 proxy_protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupServerArgs']]]] = None,
                 session_persistence_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 session_persistence_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupTagArgs']]]] = None,
                 timestamp_remove_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NlbServerGroup resource.
        :param pulumi.Input[builtins.str] protocol: NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        :param pulumi.Input[builtins.str] vpc_id: 服务器组所属私有网络的ID。
        :param pulumi.Input[builtins.bool] any_port_enabled: 是否开启全端口转发。
        :param pulumi.Input[builtins.bool] bypass_security_group_enabled: 是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        :param pulumi.Input[builtins.bool] connection_drain_enabled: 是否开启连接优雅中断。
        :param pulumi.Input[builtins.int] connection_drain_timeout: 连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input['NlbServerGroupHealthCheckArgs'] health_check: 健康检查相关参数。
        :param pulumi.Input[builtins.str] ip_address_version: 服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        :param pulumi.Input[builtins.bool] preserve_client_ip_enabled: 是否开启源地址保持。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] proxy_protocol_type: 是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        :param pulumi.Input[builtins.str] scheduler: NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        :param pulumi.Input[builtins.str] server_group_name: 服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        :param pulumi.Input[builtins.bool] session_persistence_enabled: 是否开启会话保持。
        :param pulumi.Input[builtins.int] session_persistence_timeout: 会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        :param pulumi.Input[builtins.bool] timestamp_remove_enabled: 是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        :param pulumi.Input[builtins.str] type: 服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        """
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if any_port_enabled is not None:
            pulumi.set(__self__, "any_port_enabled", any_port_enabled)
        if bypass_security_group_enabled is not None:
            pulumi.set(__self__, "bypass_security_group_enabled", bypass_security_group_enabled)
        if connection_drain_enabled is not None:
            pulumi.set(__self__, "connection_drain_enabled", connection_drain_enabled)
        if connection_drain_timeout is not None:
            pulumi.set(__self__, "connection_drain_timeout", connection_drain_timeout)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check is not None:
            pulumi.set(__self__, "health_check", health_check)
        if ip_address_version is not None:
            pulumi.set(__self__, "ip_address_version", ip_address_version)
        if preserve_client_ip_enabled is not None:
            pulumi.set(__self__, "preserve_client_ip_enabled", preserve_client_ip_enabled)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if proxy_protocol_type is not None:
            pulumi.set(__self__, "proxy_protocol_type", proxy_protocol_type)
        if scheduler is not None:
            pulumi.set(__self__, "scheduler", scheduler)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if session_persistence_enabled is not None:
            pulumi.set(__self__, "session_persistence_enabled", session_persistence_enabled)
        if session_persistence_timeout is not None:
            pulumi.set(__self__, "session_persistence_timeout", session_persistence_timeout)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timestamp_remove_enabled is not None:
            pulumi.set(__self__, "timestamp_remove_enabled", timestamp_remove_enabled)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        服务器组所属私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @any_port_enabled.setter
    def any_port_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "any_port_enabled", value)

    @property
    @pulumi.getter(name="bypassSecurityGroupEnabled")
    def bypass_security_group_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        """
        return pulumi.get(self, "bypass_security_group_enabled")

    @bypass_security_group_enabled.setter
    def bypass_security_group_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "bypass_security_group_enabled", value)

    @property
    @pulumi.getter(name="connectionDrainEnabled")
    def connection_drain_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启连接优雅中断。
        """
        return pulumi.get(self, "connection_drain_enabled")

    @connection_drain_enabled.setter
    def connection_drain_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "connection_drain_enabled", value)

    @property
    @pulumi.getter(name="connectionDrainTimeout")
    def connection_drain_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        """
        return pulumi.get(self, "connection_drain_timeout")

    @connection_drain_timeout.setter
    def connection_drain_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connection_drain_timeout", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> Optional[pulumi.Input['NlbServerGroupHealthCheckArgs']]:
        """
        健康检查相关参数。
        """
        return pulumi.get(self, "health_check")

    @health_check.setter
    def health_check(self, value: Optional[pulumi.Input['NlbServerGroupHealthCheckArgs']]):
        pulumi.set(self, "health_check", value)

    @property
    @pulumi.getter(name="ipAddressVersion")
    def ip_address_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        """
        return pulumi.get(self, "ip_address_version")

    @ip_address_version.setter
    def ip_address_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address_version", value)

    @property
    @pulumi.getter(name="preserveClientIpEnabled")
    def preserve_client_ip_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启源地址保持。
        """
        return pulumi.get(self, "preserve_client_ip_enabled")

    @preserve_client_ip_enabled.setter
    def preserve_client_ip_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "preserve_client_ip_enabled", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="proxyProtocolType")
    def proxy_protocol_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        """
        return pulumi.get(self, "proxy_protocol_type")

    @proxy_protocol_type.setter
    def proxy_protocol_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "proxy_protocol_type", value)

    @property
    @pulumi.getter
    def scheduler(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        """
        return pulumi.get(self, "scheduler")

    @scheduler.setter
    def scheduler(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduler", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupServerArgs']]]]:
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter(name="sessionPersistenceEnabled")
    def session_persistence_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启会话保持。
        """
        return pulumi.get(self, "session_persistence_enabled")

    @session_persistence_enabled.setter
    def session_persistence_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "session_persistence_enabled", value)

    @property
    @pulumi.getter(name="sessionPersistenceTimeout")
    def session_persistence_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        """
        return pulumi.get(self, "session_persistence_timeout")

    @session_persistence_timeout.setter
    def session_persistence_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "session_persistence_timeout", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="timestampRemoveEnabled")
    def timestamp_remove_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        """
        return pulumi.get(self, "timestamp_remove_enabled")

    @timestamp_remove_enabled.setter
    def timestamp_remove_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "timestamp_remove_enabled", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _NlbServerGroupState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 any_port_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bypass_security_group_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input['NlbServerGroupHealthCheckArgs']] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 preserve_client_ip_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 proxy_protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 related_load_balancer_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_count: Optional[pulumi.Input[builtins.int]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupServerArgs']]]] = None,
                 session_persistence_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 session_persistence_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupTagArgs']]]] = None,
                 timestamp_remove_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NlbServerGroup resources.
        :param pulumi.Input[builtins.str] account_id: 账号ID。
        :param pulumi.Input[builtins.bool] any_port_enabled: 是否开启全端口转发。
        :param pulumi.Input[builtins.bool] bypass_security_group_enabled: 是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        :param pulumi.Input[builtins.bool] connection_drain_enabled: 是否开启连接优雅中断。
        :param pulumi.Input[builtins.int] connection_drain_timeout: 连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        :param pulumi.Input[builtins.str] created_time: 后端服务器组的创建时间。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input['NlbServerGroupHealthCheckArgs'] health_check: 健康检查相关参数。
        :param pulumi.Input[builtins.str] ip_address_version: 服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        :param pulumi.Input[builtins.bool] preserve_client_ip_enabled: 是否开启源地址保持。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] protocol: NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        :param pulumi.Input[builtins.str] proxy_protocol_type: 是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] related_load_balancer_ids: 服务器组关联的NLB实例。
        :param pulumi.Input[builtins.str] scheduler: NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        :param pulumi.Input[builtins.int] server_count: 服务器组中后端服务器的数量。
        :param pulumi.Input[builtins.str] server_group_id: 服务器组ID。
        :param pulumi.Input[builtins.str] server_group_name: 服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        :param pulumi.Input[builtins.bool] session_persistence_enabled: 是否开启会话保持。
        :param pulumi.Input[builtins.int] session_persistence_timeout: 会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        :param pulumi.Input[builtins.str] status: 服务器组的状态。
        :param pulumi.Input[builtins.bool] timestamp_remove_enabled: 是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        :param pulumi.Input[builtins.str] type: 服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        :param pulumi.Input[builtins.str] updated_time: 后端服务器组的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 服务器组所属私有网络的ID。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if any_port_enabled is not None:
            pulumi.set(__self__, "any_port_enabled", any_port_enabled)
        if bypass_security_group_enabled is not None:
            pulumi.set(__self__, "bypass_security_group_enabled", bypass_security_group_enabled)
        if connection_drain_enabled is not None:
            pulumi.set(__self__, "connection_drain_enabled", connection_drain_enabled)
        if connection_drain_timeout is not None:
            pulumi.set(__self__, "connection_drain_timeout", connection_drain_timeout)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check is not None:
            pulumi.set(__self__, "health_check", health_check)
        if ip_address_version is not None:
            pulumi.set(__self__, "ip_address_version", ip_address_version)
        if preserve_client_ip_enabled is not None:
            pulumi.set(__self__, "preserve_client_ip_enabled", preserve_client_ip_enabled)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if proxy_protocol_type is not None:
            pulumi.set(__self__, "proxy_protocol_type", proxy_protocol_type)
        if related_load_balancer_ids is not None:
            pulumi.set(__self__, "related_load_balancer_ids", related_load_balancer_ids)
        if scheduler is not None:
            pulumi.set(__self__, "scheduler", scheduler)
        if server_count is not None:
            pulumi.set(__self__, "server_count", server_count)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if session_persistence_enabled is not None:
            pulumi.set(__self__, "session_persistence_enabled", session_persistence_enabled)
        if session_persistence_timeout is not None:
            pulumi.set(__self__, "session_persistence_timeout", session_persistence_timeout)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timestamp_remove_enabled is not None:
            pulumi.set(__self__, "timestamp_remove_enabled", timestamp_remove_enabled)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @any_port_enabled.setter
    def any_port_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "any_port_enabled", value)

    @property
    @pulumi.getter(name="bypassSecurityGroupEnabled")
    def bypass_security_group_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        """
        return pulumi.get(self, "bypass_security_group_enabled")

    @bypass_security_group_enabled.setter
    def bypass_security_group_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "bypass_security_group_enabled", value)

    @property
    @pulumi.getter(name="connectionDrainEnabled")
    def connection_drain_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启连接优雅中断。
        """
        return pulumi.get(self, "connection_drain_enabled")

    @connection_drain_enabled.setter
    def connection_drain_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "connection_drain_enabled", value)

    @property
    @pulumi.getter(name="connectionDrainTimeout")
    def connection_drain_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        """
        return pulumi.get(self, "connection_drain_timeout")

    @connection_drain_timeout.setter
    def connection_drain_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connection_drain_timeout", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> Optional[pulumi.Input['NlbServerGroupHealthCheckArgs']]:
        """
        健康检查相关参数。
        """
        return pulumi.get(self, "health_check")

    @health_check.setter
    def health_check(self, value: Optional[pulumi.Input['NlbServerGroupHealthCheckArgs']]):
        pulumi.set(self, "health_check", value)

    @property
    @pulumi.getter(name="ipAddressVersion")
    def ip_address_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        """
        return pulumi.get(self, "ip_address_version")

    @ip_address_version.setter
    def ip_address_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address_version", value)

    @property
    @pulumi.getter(name="preserveClientIpEnabled")
    def preserve_client_ip_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启源地址保持。
        """
        return pulumi.get(self, "preserve_client_ip_enabled")

    @preserve_client_ip_enabled.setter
    def preserve_client_ip_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "preserve_client_ip_enabled", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="proxyProtocolType")
    def proxy_protocol_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        """
        return pulumi.get(self, "proxy_protocol_type")

    @proxy_protocol_type.setter
    def proxy_protocol_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "proxy_protocol_type", value)

    @property
    @pulumi.getter(name="relatedLoadBalancerIds")
    def related_load_balancer_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        服务器组关联的NLB实例。
        """
        return pulumi.get(self, "related_load_balancer_ids")

    @related_load_balancer_ids.setter
    def related_load_balancer_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "related_load_balancer_ids", value)

    @property
    @pulumi.getter
    def scheduler(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        """
        return pulumi.get(self, "scheduler")

    @scheduler.setter
    def scheduler(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduler", value)

    @property
    @pulumi.getter(name="serverCount")
    def server_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        服务器组中后端服务器的数量。
        """
        return pulumi.get(self, "server_count")

    @server_count.setter
    def server_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "server_count", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupServerArgs']]]]:
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter(name="sessionPersistenceEnabled")
    def session_persistence_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启会话保持。
        """
        return pulumi.get(self, "session_persistence_enabled")

    @session_persistence_enabled.setter
    def session_persistence_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "session_persistence_enabled", value)

    @property
    @pulumi.getter(name="sessionPersistenceTimeout")
    def session_persistence_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        """
        return pulumi.get(self, "session_persistence_timeout")

    @session_persistence_timeout.setter
    def session_persistence_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "session_persistence_timeout", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组的状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbServerGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="timestampRemoveEnabled")
    def timestamp_remove_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        """
        return pulumi.get(self, "timestamp_remove_enabled")

    @timestamp_remove_enabled.setter
    def timestamp_remove_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "timestamp_remove_enabled", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组所属私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:clb/nlbServerGroup:NlbServerGroup")
class NlbServerGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 any_port_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bypass_security_group_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input[Union['NlbServerGroupHealthCheckArgs', 'NlbServerGroupHealthCheckArgsDict']]] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 preserve_client_ip_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 proxy_protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbServerGroupServerArgs', 'NlbServerGroupServerArgsDict']]]]] = None,
                 session_persistence_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 session_persistence_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbServerGroupTagArgs', 'NlbServerGroupTagArgsDict']]]]] = None,
                 timestamp_remove_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        服务器组是一组后端服务器。

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlbServerGroup:NlbServerGroup example "server_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] any_port_enabled: 是否开启全端口转发。
        :param pulumi.Input[builtins.bool] bypass_security_group_enabled: 是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        :param pulumi.Input[builtins.bool] connection_drain_enabled: 是否开启连接优雅中断。
        :param pulumi.Input[builtins.int] connection_drain_timeout: 连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input[Union['NlbServerGroupHealthCheckArgs', 'NlbServerGroupHealthCheckArgsDict']] health_check: 健康检查相关参数。
        :param pulumi.Input[builtins.str] ip_address_version: 服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        :param pulumi.Input[builtins.bool] preserve_client_ip_enabled: 是否开启源地址保持。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] protocol: NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        :param pulumi.Input[builtins.str] proxy_protocol_type: 是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        :param pulumi.Input[builtins.str] scheduler: NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        :param pulumi.Input[builtins.str] server_group_name: 服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        :param pulumi.Input[builtins.bool] session_persistence_enabled: 是否开启会话保持。
        :param pulumi.Input[builtins.int] session_persistence_timeout: 会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        :param pulumi.Input[builtins.bool] timestamp_remove_enabled: 是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        :param pulumi.Input[builtins.str] type: 服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        :param pulumi.Input[builtins.str] vpc_id: 服务器组所属私有网络的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NlbServerGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        服务器组是一组后端服务器。

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlbServerGroup:NlbServerGroup example "server_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param NlbServerGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NlbServerGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 any_port_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bypass_security_group_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_drain_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input[Union['NlbServerGroupHealthCheckArgs', 'NlbServerGroupHealthCheckArgsDict']]] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 preserve_client_ip_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 proxy_protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbServerGroupServerArgs', 'NlbServerGroupServerArgsDict']]]]] = None,
                 session_persistence_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 session_persistence_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbServerGroupTagArgs', 'NlbServerGroupTagArgsDict']]]]] = None,
                 timestamp_remove_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NlbServerGroupArgs.__new__(NlbServerGroupArgs)

            __props__.__dict__["any_port_enabled"] = any_port_enabled
            __props__.__dict__["bypass_security_group_enabled"] = bypass_security_group_enabled
            __props__.__dict__["connection_drain_enabled"] = connection_drain_enabled
            __props__.__dict__["connection_drain_timeout"] = connection_drain_timeout
            __props__.__dict__["description"] = description
            __props__.__dict__["health_check"] = health_check
            __props__.__dict__["ip_address_version"] = ip_address_version
            __props__.__dict__["preserve_client_ip_enabled"] = preserve_client_ip_enabled
            __props__.__dict__["project_name"] = project_name
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["proxy_protocol_type"] = proxy_protocol_type
            __props__.__dict__["scheduler"] = scheduler
            __props__.__dict__["server_group_name"] = server_group_name
            __props__.__dict__["servers"] = servers
            __props__.__dict__["session_persistence_enabled"] = session_persistence_enabled
            __props__.__dict__["session_persistence_timeout"] = session_persistence_timeout
            __props__.__dict__["tags"] = tags
            __props__.__dict__["timestamp_remove_enabled"] = timestamp_remove_enabled
            __props__.__dict__["type"] = type
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["related_load_balancer_ids"] = None
            __props__.__dict__["server_count"] = None
            __props__.__dict__["server_group_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(NlbServerGroup, __self__).__init__(
            'bytepluscc:clb/nlbServerGroup:NlbServerGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            any_port_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            bypass_security_group_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            connection_drain_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            connection_drain_timeout: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            health_check: Optional[pulumi.Input[Union['NlbServerGroupHealthCheckArgs', 'NlbServerGroupHealthCheckArgsDict']]] = None,
            ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
            preserve_client_ip_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            proxy_protocol_type: Optional[pulumi.Input[builtins.str]] = None,
            related_load_balancer_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            scheduler: Optional[pulumi.Input[builtins.str]] = None,
            server_count: Optional[pulumi.Input[builtins.int]] = None,
            server_group_id: Optional[pulumi.Input[builtins.str]] = None,
            server_group_name: Optional[pulumi.Input[builtins.str]] = None,
            servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbServerGroupServerArgs', 'NlbServerGroupServerArgsDict']]]]] = None,
            session_persistence_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            session_persistence_timeout: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbServerGroupTagArgs', 'NlbServerGroupTagArgsDict']]]]] = None,
            timestamp_remove_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'NlbServerGroup':
        """
        Get an existing NlbServerGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 账号ID。
        :param pulumi.Input[builtins.bool] any_port_enabled: 是否开启全端口转发。
        :param pulumi.Input[builtins.bool] bypass_security_group_enabled: 是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        :param pulumi.Input[builtins.bool] connection_drain_enabled: 是否开启连接优雅中断。
        :param pulumi.Input[builtins.int] connection_drain_timeout: 连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        :param pulumi.Input[builtins.str] created_time: 后端服务器组的创建时间。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input[Union['NlbServerGroupHealthCheckArgs', 'NlbServerGroupHealthCheckArgsDict']] health_check: 健康检查相关参数。
        :param pulumi.Input[builtins.str] ip_address_version: 服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        :param pulumi.Input[builtins.bool] preserve_client_ip_enabled: 是否开启源地址保持。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] protocol: NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        :param pulumi.Input[builtins.str] proxy_protocol_type: 是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] related_load_balancer_ids: 服务器组关联的NLB实例。
        :param pulumi.Input[builtins.str] scheduler: NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        :param pulumi.Input[builtins.int] server_count: 服务器组中后端服务器的数量。
        :param pulumi.Input[builtins.str] server_group_id: 服务器组ID。
        :param pulumi.Input[builtins.str] server_group_name: 服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        :param pulumi.Input[builtins.bool] session_persistence_enabled: 是否开启会话保持。
        :param pulumi.Input[builtins.int] session_persistence_timeout: 会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        :param pulumi.Input[builtins.str] status: 服务器组的状态。
        :param pulumi.Input[builtins.bool] timestamp_remove_enabled: 是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        :param pulumi.Input[builtins.str] type: 服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        :param pulumi.Input[builtins.str] updated_time: 后端服务器组的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 服务器组所属私有网络的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NlbServerGroupState.__new__(_NlbServerGroupState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["any_port_enabled"] = any_port_enabled
        __props__.__dict__["bypass_security_group_enabled"] = bypass_security_group_enabled
        __props__.__dict__["connection_drain_enabled"] = connection_drain_enabled
        __props__.__dict__["connection_drain_timeout"] = connection_drain_timeout
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["health_check"] = health_check
        __props__.__dict__["ip_address_version"] = ip_address_version
        __props__.__dict__["preserve_client_ip_enabled"] = preserve_client_ip_enabled
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["proxy_protocol_type"] = proxy_protocol_type
        __props__.__dict__["related_load_balancer_ids"] = related_load_balancer_ids
        __props__.__dict__["scheduler"] = scheduler
        __props__.__dict__["server_count"] = server_count
        __props__.__dict__["server_group_id"] = server_group_id
        __props__.__dict__["server_group_name"] = server_group_name
        __props__.__dict__["servers"] = servers
        __props__.__dict__["session_persistence_enabled"] = session_persistence_enabled
        __props__.__dict__["session_persistence_timeout"] = session_persistence_timeout
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["timestamp_remove_enabled"] = timestamp_remove_enabled
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        return NlbServerGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @property
    @pulumi.getter(name="bypassSecurityGroupEnabled")
    def bypass_security_group_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        """
        return pulumi.get(self, "bypass_security_group_enabled")

    @property
    @pulumi.getter(name="connectionDrainEnabled")
    def connection_drain_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启连接优雅中断。
        """
        return pulumi.get(self, "connection_drain_enabled")

    @property
    @pulumi.getter(name="connectionDrainTimeout")
    def connection_drain_timeout(self) -> pulumi.Output[builtins.int]:
        """
        连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        """
        return pulumi.get(self, "connection_drain_timeout")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> pulumi.Output['outputs.NlbServerGroupHealthCheck']:
        """
        健康检查相关参数。
        """
        return pulumi.get(self, "health_check")

    @property
    @pulumi.getter(name="ipAddressVersion")
    def ip_address_version(self) -> pulumi.Output[builtins.str]:
        """
        服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        """
        return pulumi.get(self, "ip_address_version")

    @property
    @pulumi.getter(name="preserveClientIpEnabled")
    def preserve_client_ip_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启源地址保持。
        """
        return pulumi.get(self, "preserve_client_ip_enabled")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="proxyProtocolType")
    def proxy_protocol_type(self) -> pulumi.Output[builtins.str]:
        """
        是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        """
        return pulumi.get(self, "proxy_protocol_type")

    @property
    @pulumi.getter(name="relatedLoadBalancerIds")
    def related_load_balancer_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        服务器组关联的NLB实例。
        """
        return pulumi.get(self, "related_load_balancer_ids")

    @property
    @pulumi.getter
    def scheduler(self) -> pulumi.Output[builtins.str]:
        """
        NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        """
        return pulumi.get(self, "scheduler")

    @property
    @pulumi.getter(name="serverCount")
    def server_count(self) -> pulumi.Output[builtins.int]:
        """
        服务器组中后端服务器的数量。
        """
        return pulumi.get(self, "server_count")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> pulumi.Output[builtins.str]:
        """
        服务器组ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> pulumi.Output[builtins.str]:
        """
        服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @property
    @pulumi.getter
    def servers(self) -> pulumi.Output[Sequence['outputs.NlbServerGroupServer']]:
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter(name="sessionPersistenceEnabled")
    def session_persistence_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启会话保持。
        """
        return pulumi.get(self, "session_persistence_enabled")

    @property
    @pulumi.getter(name="sessionPersistenceTimeout")
    def session_persistence_timeout(self) -> pulumi.Output[builtins.int]:
        """
        会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        """
        return pulumi.get(self, "session_persistence_timeout")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        服务器组的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NlbServerGroupTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="timestampRemoveEnabled")
    def timestamp_remove_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        """
        return pulumi.get(self, "timestamp_remove_enabled")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        服务器组所属私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PrefixListArgs', 'PrefixList']

@pulumi.input_type
class PrefixListArgs:
    def __init__(__self__, *,
                 max_entries: pulumi.Input[builtins.int],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 prefix_list_entries: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListEntryArgs']]]] = None,
                 prefix_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListTagArgs']]]] = None):
        """
        The set of arguments for constructing a PrefixList resource.
        :param pulumi.Input[builtins.int] max_entries: 最大条目数，即前缀列表最多可添加条目的数量。取值范围为1～200。
        :param pulumi.Input[builtins.str] description: 前缀列表的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] ip_version: IP版本类型。取值：IPv4（默认值）：IPv4类型。IPv6：IPv6类型。
        :param pulumi.Input[builtins.str] prefix_list_name: 前缀列表的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。
        :param pulumi.Input[builtins.str] project_name: 前缀列表所属项目的名称，不填默认加入default项目。
        """
        pulumi.set(__self__, "max_entries", max_entries)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if prefix_list_entries is not None:
            pulumi.set(__self__, "prefix_list_entries", prefix_list_entries)
        if prefix_list_name is not None:
            pulumi.set(__self__, "prefix_list_name", prefix_list_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> pulumi.Input[builtins.int]:
        """
        最大条目数，即前缀列表最多可添加条目的数量。取值范围为1～200。
        """
        return pulumi.get(self, "max_entries")

    @max_entries.setter
    def max_entries(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "max_entries", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP版本类型。取值：IPv4（默认值）：IPv4类型。IPv6：IPv6类型。
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="prefixListEntries")
    def prefix_list_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListEntryArgs']]]]:
        return pulumi.get(self, "prefix_list_entries")

    @prefix_list_entries.setter
    def prefix_list_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListEntryArgs']]]]):
        pulumi.set(self, "prefix_list_entries", value)

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。
        """
        return pulumi.get(self, "prefix_list_name")

    @prefix_list_name.setter
    def prefix_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prefix_list_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表所属项目的名称，不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _PrefixListState:
    def __init__(__self__, *,
                 association_count: Optional[pulumi.Input[builtins.int]] = None,
                 associations_route_tables: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListAssociationsRouteTableArgs']]]] = None,
                 associations_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListAssociationsSecurityGroupArgs']]]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 max_entries: Optional[pulumi.Input[builtins.int]] = None,
                 prefix_list_entries: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListEntryArgs']]]] = None,
                 prefix_list_id: Optional[pulumi.Input[builtins.str]] = None,
                 prefix_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering PrefixList resources.
        :param pulumi.Input[builtins.int] association_count: 前缀列表关联的资源数量。
        :param pulumi.Input[builtins.str] created_time: 前缀列表的创建时间。
        :param pulumi.Input[builtins.str] description: 前缀列表的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] ip_version: IP版本类型。取值：IPv4（默认值）：IPv4类型。IPv6：IPv6类型。
        :param pulumi.Input[builtins.int] max_entries: 最大条目数，即前缀列表最多可添加条目的数量。取值范围为1～200。
        :param pulumi.Input[builtins.str] prefix_list_id: 前缀列表的ID。
        :param pulumi.Input[builtins.str] prefix_list_name: 前缀列表的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。
        :param pulumi.Input[builtins.str] project_name: 前缀列表所属项目的名称，不填默认加入default项目。
        :param pulumi.Input[builtins.str] status: 前缀列表的状态。取值：Available：可用；Creating：创建中；Deleting：删除中；Pending：修改中。
        :param pulumi.Input[builtins.str] updated_time: 前缀列表的最近一次修改时间。
        """
        if association_count is not None:
            pulumi.set(__self__, "association_count", association_count)
        if associations_route_tables is not None:
            pulumi.set(__self__, "associations_route_tables", associations_route_tables)
        if associations_security_groups is not None:
            pulumi.set(__self__, "associations_security_groups", associations_security_groups)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if max_entries is not None:
            pulumi.set(__self__, "max_entries", max_entries)
        if prefix_list_entries is not None:
            pulumi.set(__self__, "prefix_list_entries", prefix_list_entries)
        if prefix_list_id is not None:
            pulumi.set(__self__, "prefix_list_id", prefix_list_id)
        if prefix_list_name is not None:
            pulumi.set(__self__, "prefix_list_name", prefix_list_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="associationCount")
    def association_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        前缀列表关联的资源数量。
        """
        return pulumi.get(self, "association_count")

    @association_count.setter
    def association_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "association_count", value)

    @property
    @pulumi.getter(name="associationsRouteTables")
    def associations_route_tables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListAssociationsRouteTableArgs']]]]:
        return pulumi.get(self, "associations_route_tables")

    @associations_route_tables.setter
    def associations_route_tables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListAssociationsRouteTableArgs']]]]):
        pulumi.set(self, "associations_route_tables", value)

    @property
    @pulumi.getter(name="associationsSecurityGroups")
    def associations_security_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListAssociationsSecurityGroupArgs']]]]:
        return pulumi.get(self, "associations_security_groups")

    @associations_security_groups.setter
    def associations_security_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListAssociationsSecurityGroupArgs']]]]):
        pulumi.set(self, "associations_security_groups", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP版本类型。取值：IPv4（默认值）：IPv4类型。IPv6：IPv6类型。
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大条目数，即前缀列表最多可添加条目的数量。取值范围为1～200。
        """
        return pulumi.get(self, "max_entries")

    @max_entries.setter
    def max_entries(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_entries", value)

    @property
    @pulumi.getter(name="prefixListEntries")
    def prefix_list_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListEntryArgs']]]]:
        return pulumi.get(self, "prefix_list_entries")

    @prefix_list_entries.setter
    def prefix_list_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListEntryArgs']]]]):
        pulumi.set(self, "prefix_list_entries", value)

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的ID。
        """
        return pulumi.get(self, "prefix_list_id")

    @prefix_list_id.setter
    def prefix_list_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prefix_list_id", value)

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。
        """
        return pulumi.get(self, "prefix_list_name")

    @prefix_list_name.setter
    def prefix_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prefix_list_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表所属项目的名称，不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的状态。取值：Available：可用；Creating：创建中；Deleting：删除中；Pending：修改中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        前缀列表的最近一次修改时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vpc/prefixList:PrefixList")
class PrefixList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 max_entries: Optional[pulumi.Input[builtins.int]] = None,
                 prefix_list_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListPrefixListEntryArgs', 'PrefixListPrefixListEntryArgsDict']]]]] = None,
                 prefix_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListTagArgs', 'PrefixListTagArgsDict']]]]] = None,
                 __props__=None):
        """
        前缀列表是一组CIDR地址块的集合，用于简化安全组规则、路由表条目的配置。当前缀列表修改时，所有关联它的资源均会同步修改。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        prefixlist_demo = bytepluscc.vpc.PrefixList("PrefixlistDemo",
            description="PrefixlistDemo Example",
            ip_version="IPv4",
            max_entries=20,
            prefix_list_name="my-prefix-list",
            project_name="default",
            prefix_list_entries=[{
                "cidr": "192.168.0.0/*",
                "description": "privite description",
            }],
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/prefixList:PrefixList example "prefix_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 前缀列表的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] ip_version: IP版本类型。取值：IPv4（默认值）：IPv4类型。IPv6：IPv6类型。
        :param pulumi.Input[builtins.int] max_entries: 最大条目数，即前缀列表最多可添加条目的数量。取值范围为1～200。
        :param pulumi.Input[builtins.str] prefix_list_name: 前缀列表的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。
        :param pulumi.Input[builtins.str] project_name: 前缀列表所属项目的名称，不填默认加入default项目。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PrefixListArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        前缀列表是一组CIDR地址块的集合，用于简化安全组规则、路由表条目的配置。当前缀列表修改时，所有关联它的资源均会同步修改。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        prefixlist_demo = bytepluscc.vpc.PrefixList("PrefixlistDemo",
            description="PrefixlistDemo Example",
            ip_version="IPv4",
            max_entries=20,
            prefix_list_name="my-prefix-list",
            project_name="default",
            prefix_list_entries=[{
                "cidr": "192.168.0.0/*",
                "description": "privite description",
            }],
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/prefixList:PrefixList example "prefix_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param PrefixListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrefixListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 max_entries: Optional[pulumi.Input[builtins.int]] = None,
                 prefix_list_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListPrefixListEntryArgs', 'PrefixListPrefixListEntryArgsDict']]]]] = None,
                 prefix_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListTagArgs', 'PrefixListTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrefixListArgs.__new__(PrefixListArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["ip_version"] = ip_version
            if max_entries is None and not opts.urn:
                raise TypeError("Missing required property 'max_entries'")
            __props__.__dict__["max_entries"] = max_entries
            __props__.__dict__["prefix_list_entries"] = prefix_list_entries
            __props__.__dict__["prefix_list_name"] = prefix_list_name
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["association_count"] = None
            __props__.__dict__["associations_route_tables"] = None
            __props__.__dict__["associations_security_groups"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["prefix_list_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(PrefixList, __self__).__init__(
            'bytepluscc:vpc/prefixList:PrefixList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            association_count: Optional[pulumi.Input[builtins.int]] = None,
            associations_route_tables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListAssociationsRouteTableArgs', 'PrefixListAssociationsRouteTableArgsDict']]]]] = None,
            associations_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListAssociationsSecurityGroupArgs', 'PrefixListAssociationsSecurityGroupArgsDict']]]]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ip_version: Optional[pulumi.Input[builtins.str]] = None,
            max_entries: Optional[pulumi.Input[builtins.int]] = None,
            prefix_list_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListPrefixListEntryArgs', 'PrefixListPrefixListEntryArgsDict']]]]] = None,
            prefix_list_id: Optional[pulumi.Input[builtins.str]] = None,
            prefix_list_name: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrefixListTagArgs', 'PrefixListTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'PrefixList':
        """
        Get an existing PrefixList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] association_count: 前缀列表关联的资源数量。
        :param pulumi.Input[builtins.str] created_time: 前缀列表的创建时间。
        :param pulumi.Input[builtins.str] description: 前缀列表的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] ip_version: IP版本类型。取值：IPv4（默认值）：IPv4类型。IPv6：IPv6类型。
        :param pulumi.Input[builtins.int] max_entries: 最大条目数，即前缀列表最多可添加条目的数量。取值范围为1～200。
        :param pulumi.Input[builtins.str] prefix_list_id: 前缀列表的ID。
        :param pulumi.Input[builtins.str] prefix_list_name: 前缀列表的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。
        :param pulumi.Input[builtins.str] project_name: 前缀列表所属项目的名称，不填默认加入default项目。
        :param pulumi.Input[builtins.str] status: 前缀列表的状态。取值：Available：可用；Creating：创建中；Deleting：删除中；Pending：修改中。
        :param pulumi.Input[builtins.str] updated_time: 前缀列表的最近一次修改时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrefixListState.__new__(_PrefixListState)

        __props__.__dict__["association_count"] = association_count
        __props__.__dict__["associations_route_tables"] = associations_route_tables
        __props__.__dict__["associations_security_groups"] = associations_security_groups
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["max_entries"] = max_entries
        __props__.__dict__["prefix_list_entries"] = prefix_list_entries
        __props__.__dict__["prefix_list_id"] = prefix_list_id
        __props__.__dict__["prefix_list_name"] = prefix_list_name
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return PrefixList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="associationCount")
    def association_count(self) -> pulumi.Output[builtins.int]:
        """
        前缀列表关联的资源数量。
        """
        return pulumi.get(self, "association_count")

    @property
    @pulumi.getter(name="associationsRouteTables")
    def associations_route_tables(self) -> pulumi.Output[Sequence['outputs.PrefixListAssociationsRouteTable']]:
        return pulumi.get(self, "associations_route_tables")

    @property
    @pulumi.getter(name="associationsSecurityGroups")
    def associations_security_groups(self) -> pulumi.Output[Sequence['outputs.PrefixListAssociationsSecurityGroup']]:
        return pulumi.get(self, "associations_security_groups")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        前缀列表的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        前缀列表的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[builtins.str]:
        """
        IP版本类型。取值：IPv4（默认值）：IPv4类型。IPv6：IPv6类型。
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> pulumi.Output[builtins.int]:
        """
        最大条目数，即前缀列表最多可添加条目的数量。取值范围为1～200。
        """
        return pulumi.get(self, "max_entries")

    @property
    @pulumi.getter(name="prefixListEntries")
    def prefix_list_entries(self) -> pulumi.Output[Sequence['outputs.PrefixListPrefixListEntry']]:
        return pulumi.get(self, "prefix_list_entries")

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> pulumi.Output[builtins.str]:
        """
        前缀列表的ID。
        """
        return pulumi.get(self, "prefix_list_id")

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> pulumi.Output[builtins.str]:
        """
        前缀列表的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。
        """
        return pulumi.get(self, "prefix_list_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        前缀列表所属项目的名称，不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        前缀列表的状态。取值：Available：可用；Creating：创建中；Deleting：删除中；Pending：修改中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.PrefixListTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        前缀列表的最近一次修改时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NameSpaceArgs', 'NameSpace']

@pulumi.input_type
class NameSpaceArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 registry: pulumi.Input[builtins.str],
                 project: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NameSpace resource.
        :param pulumi.Input[builtins.str] name: 命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        :param pulumi.Input[builtins.str] registry: 指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        :param pulumi.Input[builtins.str] project: 命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "registry", registry)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def registry(self) -> pulumi.Input[builtins.str]:
        """
        指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        """
        return pulumi.get(self, "registry")

    @registry.setter
    def registry(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "registry", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _NameSpaceState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 registry: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NameSpace resources.
        :param pulumi.Input[builtins.str] created_time: 命名空间的创建时间。
        :param pulumi.Input[builtins.str] name: 命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        :param pulumi.Input[builtins.str] project: 命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        :param pulumi.Input[builtins.str] registry: 指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if registry is not None:
            pulumi.set(__self__, "registry", registry)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命名空间的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def registry(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        """
        return pulumi.get(self, "registry")

    @registry.setter
    def registry(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "registry", value)


@pulumi.type_token("bytepluscc:cr/nameSpace:NameSpace")
class NameSpace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 registry: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        命名空间是 OCI 制品仓库的集合，管理多个具有关联属性的 OCI 制品仓库。命名空间的名称通常为企业内部的组织团队名称、产品项目名称或个人自定义名称。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        namespace_demo = bytepluscc.cr.NameSpace("NamespaceDemo",
            registry="test",
            name="testnamespace",
            project="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cr/nameSpace:NameSpace example "registry|name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: 命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        :param pulumi.Input[builtins.str] project: 命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        :param pulumi.Input[builtins.str] registry: 指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NameSpaceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        命名空间是 OCI 制品仓库的集合，管理多个具有关联属性的 OCI 制品仓库。命名空间的名称通常为企业内部的组织团队名称、产品项目名称或个人自定义名称。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        namespace_demo = bytepluscc.cr.NameSpace("NamespaceDemo",
            registry="test",
            name="testnamespace",
            project="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cr/nameSpace:NameSpace example "registry|name"
        ```

        :param str resource_name: The name of the resource.
        :param NameSpaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NameSpaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 registry: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NameSpaceArgs.__new__(NameSpaceArgs)

            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["project"] = project
            if registry is None and not opts.urn:
                raise TypeError("Missing required property 'registry'")
            __props__.__dict__["registry"] = registry
            __props__.__dict__["created_time"] = None
        super(NameSpace, __self__).__init__(
            'bytepluscc:cr/nameSpace:NameSpace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            project: Optional[pulumi.Input[builtins.str]] = None,
            registry: Optional[pulumi.Input[builtins.str]] = None) -> 'NameSpace':
        """
        Get an existing NameSpace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 命名空间的创建时间。
        :param pulumi.Input[builtins.str] name: 命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        :param pulumi.Input[builtins.str] project: 命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        :param pulumi.Input[builtins.str] registry: 指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NameSpaceState.__new__(_NameSpaceState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["registry"] = registry
        return NameSpace(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        命名空间的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.str]:
        """
        命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def registry(self) -> pulumi.Output[builtins.str]:
        """
        指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        """
        return pulumi.get(self, "registry")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDatabaseResult',
    'AwaitableGetDatabaseResult',
    'get_database',
    'get_database_output',
]

@pulumi.output_type
class GetDatabaseResult:
    """
    A collection of values returned by getDatabase.
    """
    def __init__(__self__, character_set_name=None, database_privileges=None, description=None, id=None, instance_id=None, name=None, status=None):
        if character_set_name and not isinstance(character_set_name, str):
            raise TypeError("Expected argument 'character_set_name' to be a str")
        pulumi.set(__self__, "character_set_name", character_set_name)
        if database_privileges and not isinstance(database_privileges, list):
            raise TypeError("Expected argument 'database_privileges' to be a list")
        pulumi.set(__self__, "database_privileges", database_privileges)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="characterSetName")
    def character_set_name(self) -> builtins.str:
        """
        数据库字符集。目前支持的字符集包含：utf8、utf8mb4（默认）、latin1、ascii。
        """
        return pulumi.get(self, "character_set_name")

    @property
    @pulumi.getter(name="databasePrivileges")
    def database_privileges(self) -> Sequence['outputs.GetDatabaseDatabasePrivilegeResult']:
        """
        授权数据库权限信息。
        """
        return pulumi.get(self, "database_privileges")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        数据库的描述信息，长度不超过 256 个字符。该字段可选，若不设置该字段，或设置了该字段但描述信息长度为 0 ，则描述信息为空。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        数据库实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        数据库名称。命名规则如下：名称唯一。长度为 2~64 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）或中划线（-）组成。不能使用某些预留字，包括 root、admin 等。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        数据库状态。取值为：Unavailable：不可用。Available：可用。
        """
        return pulumi.get(self, "status")


class AwaitableGetDatabaseResult(GetDatabaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseResult(
            character_set_name=self.character_set_name,
            database_privileges=self.database_privileges,
            description=self.description,
            id=self.id,
            instance_id=self.instance_id,
            name=self.name,
            status=self.status)


def get_database(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseResult:
    """
    Data Source schema for Byteplus::RDSMySQL::Database


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rdsmysql/getDatabase:getDatabase', __args__, opts=opts, typ=GetDatabaseResult).value

    return AwaitableGetDatabaseResult(
        character_set_name=pulumi.get(__ret__, 'character_set_name'),
        database_privileges=pulumi.get(__ret__, 'database_privileges'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'))
def get_database_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseResult]:
    """
    Data Source schema for Byteplus::RDSMySQL::Database


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rdsmysql/getDatabase:getDatabase', __args__, opts=opts, typ=GetDatabaseResult)
    return __ret__.apply(lambda __response__: GetDatabaseResult(
        character_set_name=pulumi.get(__response__, 'character_set_name'),
        database_privileges=pulumi.get(__response__, 'database_privileges'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRouterResult',
    'AwaitableGetTransitRouterResult',
    'get_transit_router',
    'get_transit_router_output',
]

@pulumi.output_type
class GetTransitRouterResult:
    """
    A collection of values returned by getTransitRouter.
    """
    def __init__(__self__, asn=None, attachments=None, business_status=None, creation_time=None, deleted_time=None, description=None, grant_status=None, id=None, overdue_time=None, project_name=None, status=None, tags=None, transit_router_id=None, transit_router_name=None, update_time=None):
        if asn and not isinstance(asn, int):
            raise TypeError("Expected argument 'asn' to be a int")
        pulumi.set(__self__, "asn", asn)
        if attachments and not isinstance(attachments, list):
            raise TypeError("Expected argument 'attachments' to be a list")
        pulumi.set(__self__, "attachments", attachments)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if grant_status and not isinstance(grant_status, str):
            raise TypeError("Expected argument 'grant_status' to be a str")
        pulumi.set(__self__, "grant_status", grant_status)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if transit_router_id and not isinstance(transit_router_id, str):
            raise TypeError("Expected argument 'transit_router_id' to be a str")
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_name and not isinstance(transit_router_name, str):
            raise TypeError("Expected argument 'transit_router_name' to be a str")
        pulumi.set(__self__, "transit_router_name", transit_router_name)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter
    def asn(self) -> builtins.int:
        """
        中转路由器的ASN号。取值范围为64512 ～ 65534 和 4200000000 ～ 4294967294，默认值为64512。
        """
        return pulumi.get(self, "asn")

    @property
    @pulumi.getter
    def attachments(self) -> Sequence['outputs.GetTransitRouterAttachmentResult']:
        """
        网络实例连接的详细信息。
        """
        return pulumi.get(self, "attachments")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        网络实例连接的业务状态。取值如下：Normal：正常。FinancialLocked：已冻结。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        网络实例连接的创建时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        网络实例连接的删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        中转路由器实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="grantStatus")
    def grant_status(self) -> builtins.str:
        """
        实例共享的状态。Accepted：已接受。Initial：待接受。
        """
        return pulumi.get(self, "grant_status")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        中转路由器实例的欠费关停时间。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        中转路由器实例所属项目的名称。不传入该参数或该参数不传入数值时，默认为default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        中转路由器实例的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTransitRouterTagResult']:
        """
        标签列表
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> builtins.str:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterName")
    def transit_router_name(self) -> builtins.str:
        """
        中转路由器实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_name")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        中转路由器实例的最近操作时间。
        """
        return pulumi.get(self, "update_time")


class AwaitableGetTransitRouterResult(GetTransitRouterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRouterResult(
            asn=self.asn,
            attachments=self.attachments,
            business_status=self.business_status,
            creation_time=self.creation_time,
            deleted_time=self.deleted_time,
            description=self.description,
            grant_status=self.grant_status,
            id=self.id,
            overdue_time=self.overdue_time,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            transit_router_id=self.transit_router_id,
            transit_router_name=self.transit_router_name,
            update_time=self.update_time)


def get_transit_router(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRouterResult:
    """
    Data Source schema for Byteplus::TransitRouter::TransitRouter


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:transitrouter/getTransitRouter:getTransitRouter', __args__, opts=opts, typ=GetTransitRouterResult).value

    return AwaitableGetTransitRouterResult(
        asn=pulumi.get(__ret__, 'asn'),
        attachments=pulumi.get(__ret__, 'attachments'),
        business_status=pulumi.get(__ret__, 'business_status'),
        creation_time=pulumi.get(__ret__, 'creation_time'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        description=pulumi.get(__ret__, 'description'),
        grant_status=pulumi.get(__ret__, 'grant_status'),
        id=pulumi.get(__ret__, 'id'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        transit_router_id=pulumi.get(__ret__, 'transit_router_id'),
        transit_router_name=pulumi.get(__ret__, 'transit_router_name'),
        update_time=pulumi.get(__ret__, 'update_time'))
def get_transit_router_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTransitRouterResult]:
    """
    Data Source schema for Byteplus::TransitRouter::TransitRouter


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:transitrouter/getTransitRouter:getTransitRouter', __args__, opts=opts, typ=GetTransitRouterResult)
    return __ret__.apply(lambda __response__: GetTransitRouterResult(
        asn=pulumi.get(__response__, 'asn'),
        attachments=pulumi.get(__response__, 'attachments'),
        business_status=pulumi.get(__response__, 'business_status'),
        creation_time=pulumi.get(__response__, 'creation_time'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        description=pulumi.get(__response__, 'description'),
        grant_status=pulumi.get(__response__, 'grant_status'),
        id=pulumi.get(__response__, 'id'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        transit_router_id=pulumi.get(__response__, 'transit_router_id'),
        transit_router_name=pulumi.get(__response__, 'transit_router_name'),
        update_time=pulumi.get(__response__, 'update_time')))
